pub enum TypeSafety {
None,
Lambda,
LambdaAndVar,
Full,
}Variants
None
No type safety checks are performed.
Lambda
When trying to execute a lambda, make sure that the popped value is a lambda.
LambdaAndVar
Include all checks from TypeSafety::Lambda, and make sure that when storing or loading a variable, the popped value is a variable name.
Full
Include all checks from TypeSafety::LambdaAndVar, and ensure that only integers can be used for arithmetic operations.